@@ -298,7 +298,9 @@ var LineRenderer = Widget.extend(FieldManagerMixin, {
             };
             self.fields.partner_id.appendTo(self.$('.accounting_view caption'));
         });
-        this.$('thead .line_info_button').attr("data-content", qweb.render('reconciliation.line.statement_line.details', {'state': this._initialState}));
+        $('<span class="line_info_button fa fa-info-circle"/>')
+            .appendTo(this.$('thead .cell_info_popover'))
+            .attr("data-content", qweb.render('reconciliation.line.statement_line.details', {'state': this._initialState}));
         this.$el.popover({
             'selector': '.line_info_button',
             'placement': 'left',
@@ -357,18 +359,21 @@ var LineRenderer = Widget.extend(FieldManagerMixin, {
 
         // loop state propositions
         var props = [];
-        var nb_debit_props = 0;
-        var nb_credit_props = 0;
+        var partialDebitProps = 0;
+        var partialCreditProps = 0;
         _.each(state.reconciliation_proposition, function (prop) {
             if (prop.display) {
                 props.push(prop);
-                if (prop.amount < 0)
-                    nb_debit_props += 1;
-                else if (prop.amount > 0)
-                    nb_credit_props += 1;
+                if (prop.amount > 0 && prop.amount > state.st_line.amount) {
+                    partialDebitProps++;
+                } else if (prop.amount < 0 && prop.amount < state.st_line.amount) {
+                    partialCreditProps++;
+                }
+
             }
         });
 
+        var targetLineAmount = state.st_line.amount;
         _.each(props, function (line) {
             var $line = $(qweb.render("reconciliation.line.mv_line", {'line': line, 'state': state}));
             if (!isNaN(line.id)) {
@@ -377,10 +382,10 @@ var LineRenderer = Widget.extend(FieldManagerMixin, {
                     .attr("data-content", qweb.render('reconciliation.line.mv_line.details', {'line': line}));
             }
             if (line.already_paid === false &&
-                ((state.balance.amount_currency < 0 || line.partial_reconcile) && nb_credit_props == 1
-                    && line.amount > 0 && state.st_line.amount > 0 && state.st_line.amount < line.amount) ||
-                ((state.balance.amount_currency > 0 || line.partial_reconcile) && nb_debit_props == 1
-                    && line.amount < 0 && state.st_line.amount < 0 && state.st_line.amount > line.amount)) {
+                ((state.balance.amount_currency < 0 || line.partial_reconcile)
+                    && line.amount > 0 && state.st_line.amount > 0 && targetLineAmount < line.amount && partialDebitProps <= 1) ||
+                ((state.balance.amount_currency > 0 || line.partial_reconcile)
+                    && line.amount < 0 && state.st_line.amount < 0 && targetLineAmount > line.amount && partialCreditProps <= 1)) {
                 var $cell = $line.find(line.amount > 0 ? '.cell_right' : '.cell_left');
                 var text;
                 if (line.partial_reconcile) {
@@ -394,6 +399,8 @@ var LineRenderer = Widget.extend(FieldManagerMixin, {
                     .prependTo($cell)
                     .attr("data-content", text);
             }
+            targetLineAmount -= line.amount;
+
             $props.append($line);
         });
 
