@@ -4,6 +4,7 @@
 import logging
 
 from odoo import api, models
+from odoo.exceptions import AccessDenied
 
 _logger = logging.getLogger(__name__)
 
@@ -36,6 +37,8 @@ class AutoVacuum(models.AbstractModel):
 
     @api.model
     def power_on(self, *args, **kwargs):
+        if not self.env.user._is_admin():
+            raise AccessDenied()
         self.env['ir.attachment']._file_gc()
         self._gc_transient_models()
         self._gc_user_logs()
