@@ -514,6 +514,9 @@ var BasicComposer = Widget.extend(chat_mixin, {
     on_click_add_attachment: function () {
         this.$('input.o_input_file').click();
         this.$input.focus();
+        // set ignoreEscape to avoid escape_pressed event when file selector dialog is opened
+        // when user press escape to cancel file selector dialog then escape_pressed event should not be trigerred
+        this.ignoreEscape = true;
     },
 
     setState: function (state) {
@@ -565,6 +568,8 @@ var BasicComposer = Widget.extend(chat_mixin, {
                 if (this.mention_manager.is_open()) {
                     event.stopPropagation();
                     this.mention_manager.reset_suggestions();
+                } else if (this.ignoreEscape) {
+                    this.ignoreEscape = false;
                 } else {
                     this.trigger_up("escape_pressed");
                 }
@@ -654,6 +659,7 @@ var BasicComposer = Widget.extend(chat_mixin, {
                 }
             });
             this.set('attachment_ids', attachments);
+            this.$('input.o_input_file').val('');
         }
     },
     do_check_attachment_upload: function () {
@@ -789,6 +795,7 @@ var BasicComposer = Widget.extend(chat_mixin, {
      * @param {MouseEvent} event
      */
     _onAttachmentView: function (event) {
+        event.stopPropagation();
         var activeAttachmentID = $(event.currentTarget).data('id');
         var attachments = this.get('attachment_ids');
         if (activeAttachmentID) {
