@@ -8,7 +8,7 @@ QUnit.module('mail', {}, function () {
 QUnit.module('Mail utils');
 
 QUnit.test('add_link utility function', function (assert) {
-    assert.expect(7);
+    assert.expect(15);
 
     var testInputs = {
         'http://admin:password@example.com:8/%2020': true,
@@ -18,12 +18,15 @@ QUnit.test('add_link utility function', function (assert) {
         'www.127.0.0.5': false,
         'should.notmatch': false,
         'fhttps://test.example.com/test': false,
+        "https://www.transifex.com/odoo/odoo-11/translate/#fr/lunch?q=text%3A'La+Tartiflette'": true,
+        'https://www.transifex.com/odoo/odoo-11/translate/#fr/$/119303430?q=text%3ATartiflette': true,
     };
 
     _.each(testInputs, function (willLinkify, content) {
         var output = utils.parse_and_transform(content, utils.add_link);
         if (willLinkify) {
             assert.strictEqual(output.indexOf('<a '), 0, "There should be a link");
+            assert.strictEqual(output.indexOf('</a>'), (output.length - 4), "Link should match the whole text");
         } else {
             assert.strictEqual(output.indexOf('<a '), -1, "There should be no link");
         }
