@@ -209,7 +209,7 @@ class MailComposer(models.TransientModel):
                         new_attachment_ids.append(attachment.copy({'res_model': 'mail.compose.message', 'res_id': wizard.id}).id)
                     else:
                         new_attachment_ids.append(attachment.id)
-                    wizard.write({'attachment_ids': [(6, 0, new_attachment_ids)]})
+                wizard.write({'attachment_ids': [(6, 0, new_attachment_ids)]})
 
             # Mass Mailing
             mass_mode = wizard.composition_mode in ('mass_mail', 'mass_post')
@@ -442,8 +442,8 @@ class MailComposer(models.TransientModel):
             multi_mode = False
             res_ids = [res_ids]
 
-        subjects = self.render_template(self.subject, self.model, res_ids)
-        bodies = self.render_template(self.body, self.model, res_ids, post_process=True)
+        subjects = self.render_template(self.subject, self.model, res_ids) if not self.template_id else False
+        bodies = self.render_template(self.body, self.model, res_ids, post_process=True) if not self.template_id else False
         emails_from = self.render_template(self.email_from, self.model, res_ids)
         replies_to = self.render_template(self.reply_to, self.model, res_ids)
         default_recipients = {}
@@ -453,8 +453,8 @@ class MailComposer(models.TransientModel):
         results = dict.fromkeys(res_ids, False)
         for res_id in res_ids:
             results[res_id] = {
-                'subject': subjects[res_id],
-                'body': bodies[res_id],
+                'subject': subjects[res_id] if subjects else False,
+                'body': bodies[res_id] if subjects else False,
                 'email_from': emails_from[res_id],
                 'reply_to': replies_to[res_id],
             }
@@ -464,7 +464,7 @@ class MailComposer(models.TransientModel):
         if self.template_id:
             template_values = self.generate_email_for_composer(
                 self.template_id.id, res_ids,
-                fields=['email_to', 'partner_to', 'email_cc', 'attachment_ids', 'mail_server_id'])
+                fields=['subject', 'body_html', 'email_to', 'partner_to', 'email_cc', 'attachment_ids', 'mail_server_id'])
         else:
             template_values = {}
 
@@ -474,6 +474,8 @@ class MailComposer(models.TransientModel):
                 results[res_id].pop('partner_ids')
                 results[res_id].pop('email_to')
                 results[res_id].pop('email_cc')
+                results[res_id].pop('subject')
+                results[res_id].pop('body')
                 # remove attachments from template values as they should not be rendered
                 template_values[res_id].pop('attachment_ids', None)
             else:
