@@ -38,7 +38,7 @@ FieldTextHtml.include({
         var datarecord = this._super();
         if (this.model === 'mail.mass_mailing') {
             // these fields can potentially get very long, let's remove them
-            datarecord = _.omit(datarecord, ['mailing_domain', 'contact_list_ids', 'body_html']);
+            datarecord = _.omit(datarecord, ['mailing_domain', 'contact_list_ids', 'body_html', 'attachment_ids']);
         }
         return datarecord;
     },
