@@ -219,6 +219,7 @@ class MrpWorkorder(models.Model):
                             'done_wo': False,
                             'location_id': move.location_id.id,
                             'location_dest_id': move.location_dest_id.id,
+                            'date': move.date,
                         })
                         qty_todo -= 1
                 elif float_compare(qty_todo, 0.0, precision_rounding=rounding) < 0:
@@ -284,6 +285,18 @@ class MrpWorkorder(models.Model):
         self.final_lot_id = self.env['stock.production.lot'].search([('use_next_on_work_order_id', '=', self.id)],
                                                                     order='create_date, id', limit=1)
 
+    def _get_byproduct_move_line(self, by_product_move, quantity):
+        return {
+            'move_id': by_product_move.id,
+            'product_id': by_product_move.product_id.id,
+            'product_uom_qty': quantity,
+            'product_uom_id': by_product_move.product_uom.id,
+            'qty_done': quantity,
+            'workorder_id': self.id,
+            'location_id': by_product_move.location_id.id,
+            'location_dest_id': by_product_move.location_dest_id.id,
+        }
+
     @api.multi
     def record_production(self):
         self.ensure_one()
@@ -345,6 +358,7 @@ class MrpWorkorder(models.Model):
                 move_line = production_move.move_line_ids.filtered(lambda x: x.lot_id.id == self.final_lot_id.id)
                 if move_line:
                     move_line.product_uom_qty += self.qty_producing
+                    move_line.qty_done += self.qty_producing
                 else:
                     move_line.create({'move_id': production_move.id,
                              'product_id': production_move.product_id.id,
@@ -361,8 +375,14 @@ class MrpWorkorder(models.Model):
 
         if not self.next_work_order_id:
             for by_product_move in self.production_id.move_finished_ids.filtered(lambda x: (x.product_id.id != self.production_id.product_id.id) and (x.state not in ('done', 'cancel'))):
-                if by_product_move.has_tracking == 'none':
-                    by_product_move.quantity_done += self.qty_producing * by_product_move.unit_factor
+                if by_product_move.has_tracking != 'serial':
+                    values = self._get_byproduct_move_line(by_product_move, self.qty_producing * by_product_move.unit_factor)
+                    self.env['stock.move.line'].create(values)
+                elif by_product_move.has_tracking == 'serial':
+                    qty_todo = by_product_move.product_uom._compute_quantity(self.qty_producing * by_product_move.unit_factor, by_product_move.product_id.uom_id)
+                    for i in range(0, int(float_round(qty_todo, precision_digits=0))):
+                        values = self._get_byproduct_move_line(by_product_move, 1)
+                        self.env['stock.move.line'].create(values)
 
         # Update workorder quantity produced
         self.qty_produced += self.qty_producing
@@ -392,7 +412,12 @@ class MrpWorkorder(models.Model):
 
     @api.multi
     def button_start(self):
-        # TDE CLEANME
+        self.ensure_one()
+        # As button_start is automatically called in the new view
+        if self.state in ('done', 'cancel'):
+            return True
+
+        # Need a loss in case of the real time exceeding the expected
         timeline = self.env['mrp.workcenter.productivity']
         if self.duration < self.duration_expected:
             loss_id = self.env['mrp.workcenter.productivity.loss'].search([('loss_type','=','productive')], limit=1)
