@@ -59,6 +59,15 @@ class PaymentAcquirerAuthorize(models.Model):
     @api.multi
     def authorize_form_generate_values(self, values):
         self.ensure_one()
+        # State code is only supported in US, use state name by default
+        # See https://developer.authorize.net/api/reference/
+        state = values['partner_state'].name if values.get('partner_state') else ''
+        if values.get('partner_country') and values.get('partner_country') == self.env.ref('base.us', False):
+            state = values['partner_state'].code if values.get('partner_state') else ''
+        billing_state = values['billing_partner_state'].name if values.get('billing_partner_state') else ''
+        if values.get('billing_partner_country') and values.get('billing_partner_country') == self.env.ref('base.us', False):
+            billing_state = values['billing_partner_state'].code if values.get('billing_partner_state') else ''
+
         base_url = self.env['ir.config_parameter'].get_param('web.base.url')
         authorize_tx_values = dict(values)
         temp_authorize_tx_values = {
@@ -83,7 +92,7 @@ class PaymentAcquirerAuthorize(models.Model):
             'first_name': values.get('partner_first_name'),
             'last_name': values.get('partner_last_name'),
             'phone': values.get('partner_phone'),
-            'state': values.get('partner_state') and values['partner_state'].code or '',
+            'state': state,
             'billing_address': values.get('billing_partner_address'),
             'billing_city': values.get('billing_partner_city'),
             'billing_country': values.get('billing_partner_country') and values.get('billing_partner_country').name or '',
@@ -92,7 +101,7 @@ class PaymentAcquirerAuthorize(models.Model):
             'billing_first_name': values.get('billing_partner_first_name'),
             'billing_last_name': values.get('billing_partner_last_name'),
             'billing_phone': values.get('billing_partner_phone'),
-            'billing_state': values.get('billing_partner_state') and values['billing_partner_state'].code or '',
+            'billing_state': billing_state,
         }
         temp_authorize_tx_values['returndata'] = authorize_tx_values.pop('return_url', '')
         temp_authorize_tx_values['x_fp_hash'] = self._authorize_generate_hashing(temp_authorize_tx_values)
