@@ -629,7 +629,24 @@ class StockQuant(TransactionCase):
         })
         quantity, in_date = self.env['stock.quant']._update_available_quantity(product1, stock_location, 1.0)
         self.assertEqual(quantity, 1)
-        self.assertEqual(in_date, None)
+        self.assertNotEqual(in_date, None)
+
+
+    def test_in_date_1b(self):
+        stock_location = self.env.ref('stock.stock_location_stock')
+        product1 = self.env['product.product'].create({
+            'name': 'Product A',
+            'type': 'product',
+        })
+        self.env['stock.quant'].create({
+            'product_id': product1.id,
+            'location_id': stock_location.id,
+            'quantity': 1.0,
+        })
+        quantity, in_date = self.env['stock.quant']._update_available_quantity(product1, stock_location, 2.0)
+        self.assertEqual(quantity, 3)
+        self.assertNotEqual(in_date, None)
+
 
     def test_in_date_2(self):
         """ Check that an incoming date is correctly set when updating the quantity of a tracked
@@ -707,6 +724,34 @@ class StockQuant(TransactionCase):
         # Removal strategy is LIFO, so lot1 should be received as it was received later.
         self.assertEqual(quants[0][0].lot_id.id, lot1.id)
 
+    def test_in_date_4b(self):
+        """ Check for LIFO and max with/without in_date that it handles the LIFO NULLS LAST well
+        """
+        stock_location = self.env.ref('stock.stock_location_stock')
+        stock_location1 = self.env.ref('stock.stock_location_components')
+        stock_location2 = self.env.ref('stock.stock_location_14')
+        lifo_strategy = self.env['product.removal'].search([('method', '=', 'lifo')])
+        stock_location.removal_strategy_id = lifo_strategy
+        product1 = self.env['product.product'].create({
+            'name': 'Product A',
+            'type': 'product',
+            'tracking': 'serial',
+        })
+
+        self.env['stock.quant'].create({
+            'product_id': product1.id,
+            'location_id': stock_location1.id,
+            'quantity': 1.0,
+        })
+
+        in_date_location2 = datetime.now()
+        self.env['stock.quant']._update_available_quantity(product1, stock_location2, 1.0, in_date=in_date_location2)
+
+        quants = self.env['stock.quant']._update_reserved_quantity(product1, stock_location, 1)
+
+        # Removal strategy is LIFO, so the one with date is the most recent one and should be selected
+        self.assertEqual(quants[0][0].location_id.id, stock_location2.id)
+
     def test_in_date_5(self):
         """ Receive the same lot at different times, once they're in the same location, the quants
         are merged and only the earliest incoming date is kept.
