@@ -139,14 +139,10 @@ class TestOnChange(common.TransactionCase):
         self.env.cache.invalidate()
         result = self.Discussion.onchange(values, 'name', field_onchange)
         self.assertIn('messages', result['value'])
-        self.assertItemsEqual(result['value']['messages'], [
+        self.assertEqual(result['value']['messages'], [
             (5,),
             (1, message.id, {
                 'name': "[%s] %s" % ("Foo", USER.name),
-                'body': message.body,
-                'author': message.author.name_get()[0],
-                'size': message.size,
-                'important': message.important,
             }),
             (0, 0, {
                 'name': "[%s] %s" % ("Foo", USER.name),
@@ -157,6 +153,17 @@ class TestOnChange(common.TransactionCase):
             }),
         ])
 
+        # ensure onchange changing one2many without subfield works
+        one_level_fields = {k: v for k, v in field_onchange.items() if k.count('.') < 1}
+        values = dict(values, name='{generate_dummy_message}')
+        result = self.Discussion.with_context(generate_dummy_message=True).onchange(values, 'name', one_level_fields)
+        self.assertEqual(result['value']['messages'], [
+            (5,),
+            (4, message.id),
+            (0, 0, {}),
+            (0, 0, {}),
+        ])
+
     def test_onchange_one2many_reference(self):
         """ test the effect of onchange() on one2many fields with line references """
         BODY = "What a beautiful day!"
@@ -245,8 +252,7 @@ class TestOnChange(common.TransactionCase):
             'lines': [
                 (5,),
                 (1, line1.id, {'name': partner2.name,
-                               'partner': (partner2.id, partner2.name),
-                               'tags': [(5,)]}),
+                               'partner': (partner2.id, partner2.name)}),
                 (0, 0, {'name': partner2.name,
                         'partner': (partner2.id, partner2.name),
                         'tags': [(5,)]}),
@@ -254,6 +260,17 @@ class TestOnChange(common.TransactionCase):
         })
 
         # do it again, but this time with a new tag on the second line
+        expected_new_tag_result = {
+            'name': partner2.name,
+            'lines': [
+                (5,),
+                (1, line1.id, {'name': partner2.name,
+                               'partner': (partner2.id, partner2.name)}),
+                (0, 0, {'name': partner2.name,
+                        'partner': (partner2.id, partner2.name),
+                        'tags': [(5,), (0, 0, {'name': 'Tag'})]}),
+            ],
+        }
         values = {
             'name': partner1.name,
             'partner': partner2.id,             # this one just changed
@@ -265,18 +282,13 @@ class TestOnChange(common.TransactionCase):
         self.env.cache.invalidate()
 
         result = multi.onchange(values, 'partner', field_onchange)
-        self.assertEqual(result['value'], {
-            'name': partner2.name,
-            'lines': [
-                (5,),
-                (1, line1.id, {'name': partner2.name,
-                               'partner': (partner2.id, partner2.name),
-                               'tags': [(5,)]}),
-                (0, 0, {'name': partner2.name,
-                        'partner': (partner2.id, partner2.name),
-                        'tags': [(5,), (0, 0, {'name': 'Tag'})]}),
-            ],
-        })
+        self.assertEqual(result['value'], expected_new_tag_result)
+
+        # ensure ID is not returned when asked and a many2many record is set to be created
+        self.env.cache.invalidate()
+
+        result = multi.onchange(values, 'partner', dict(field_onchange, **{'lines.tags.id': None}))
+        self.assertEqual(result['value'], expected_new_tag_result)
 
     def test_onchange_specific(self):
         """ test the effect of field-specific onchange method """
@@ -308,8 +320,7 @@ class TestOnChange(common.TransactionCase):
         self.assertIn('participants', result['value'])
         self.assertItemsEqual(
             result['value']['participants'],
-            [(5,)] + [(1, user.id, {'display_name': user.display_name})
-                      for user in discussion.participants + demo],
+            [(5,)] + [(4, user.id) for user in discussion.participants + demo],
         )
 
     def test_onchange_default(self):
@@ -345,6 +356,8 @@ class TestOnChange(common.TransactionCase):
         self.assertEqual(len(discussion.messages), 3)
         messages = [(4, msg.id) for msg in discussion.messages]
         messages[0] = (1, messages[0][1], {'body': 'test onchange'})
+        lines = ["%s:%s" % (m.name, m.body) for m in discussion.messages]
+        lines[0] = "%s:%s" % (discussion.messages[0].name, 'test onchange')
         values = {
             'name': discussion.name,
             'moderator': demo.id,
@@ -355,8 +368,7 @@ class TestOnChange(common.TransactionCase):
         }
         result = discussion.onchange(values, 'messages', field_onchange)
         self.assertIn('message_concat', result['value'])
-        self.assertEqual(result['value']['message_concat'],
-                         "\n".join(["%s:%s" % (m.name, m.body) for m in discussion.messages]))
+        self.assertEqual(result['value']['message_concat'], "\n".join(lines))
 
     def test_onchange_one2many_with_domain_on_related_field(self):
         """ test the value of the one2many field when defined with a domain on a related field"""
@@ -402,28 +414,15 @@ class TestOnChange(common.TransactionCase):
             'categories': [(4, cat.id) for cat in discussion.categories],
             'messages': [(4, msg.id) for msg in discussion.messages],
             'participants': [(4, usr.id) for usr in discussion.participants],
-            'message_changes': 0,
             'important_messages': [(4, msg.id) for msg in discussion.important_messages],
             'important_emails': [(4, eml.id) for eml in discussion.important_emails],
         }
+        self.env.cache.invalidate()
         result = discussion.onchange(values, 'name', field_onchange)
 
-        # When one2many domain contains non-computed field, things are ok
-        self.assertEqual(result['value']['important_messages'],
-                         [(5,)] + [(4, msg.id) for msg in discussion.important_messages])
-
-        # But here with commit 5676d81, we get value of: [(2, email.id)]
         self.assertEqual(
             result['value']['important_emails'],
-            [(5,),
-             (1, email.id, {
-                 'name': u'[Foo Bar] %s' % USER.name,
-                 'body': email.body,
-                 'author': USER.name_get()[0],
-                 'important': True,
-                 'email_to': demo.email,
-                 'size': email.size,
-             })]
+            [(5,), (1, email.id, {'name': u'[Foo Bar] %s' % USER.name})],
         )
 
     def test_onchange_related(self):
