@@ -1975,7 +1975,13 @@ eventHandler.modules.toolbar.button.updateRecentColor = function (elBtn, sEvent,
 };
 
 $(document).on('click keyup', function () {
-    var $popover = $((range.create()||{}).sc).closest('[contenteditable]');
+    var current_range = {};
+    try {
+        current_range = range.create() || {};
+    } catch (e) {
+        // if range is on Restricted element ignore error
+    }
+    var $popover = $(current_range.sc).closest('[contenteditable]');
     var popover_history = ($popover.data()||{}).NoteHistory;
     if (!popover_history || popover_history === history) return;
     var editor = $popover.parent('.note-editor');
@@ -2262,7 +2268,7 @@ $.summernote.pluginEvents.backColor = function (event, editor, layoutInfo, backC
 };
 
 options.onCreateLink = function (sLinkUrl) {
-    if (sLinkUrl.indexOf('mailto:') === 0) {
+    if (sLinkUrl.indexOf('mailto:') === 0 || sLinkUrl.indexOf('tel:') === 0) {
       // pass
     } else if (sLinkUrl.indexOf('@') !== -1 && sLinkUrl.indexOf(':') === -1) {
       sLinkUrl =  'mailto:' + sLinkUrl;
