@@ -10,6 +10,6 @@ class IrModel(models.Model):
 
     @api.multi
     def unlink(self):
-        self.env.cr.execute(
-            "DELETE FROM ir_model_fields WHERE name='website_id'")
+        self.env.cr.execute("DELETE FROM ir_model_fields WHERE name='website_id'")
+        self.env.cr.execute("DELETE FROM res_config_settings WHERE website_id IS NOT NULL")
         return super(IrModel, self).unlink()
