@@ -10,7 +10,7 @@ import socket
 import threading
 import time
 
-from email.header import decode_header
+from email.header import decode_header, Header
 from email.utils import getaddresses, formataddr
 from lxml import etree
 
@@ -45,11 +45,12 @@ class _Cleaner(clean.Cleaner):
     _style_whitelist = [
         'font-size', 'font-family', 'font-weight', 'background-color', 'color', 'text-align',
         'line-height', 'letter-spacing', 'text-transform', 'text-decoration',
+        'float', 'vertical-align',
         'padding', 'padding-top', 'padding-left', 'padding-bottom', 'padding-right',
-        'margin', 'margin-top', 'margin-left', 'margin-bottom', 'margin-right'
+        'margin', 'margin-top', 'margin-left', 'margin-bottom', 'margin-right',
         # box model
-        'border', 'border-color', 'border-radius', 'border-style', 'height',
-        'margin', 'padding', 'width', 'max-width', 'min-width',
+        'border', 'border-color', 'border-radius', 'border-style', 'border-width',
+        'height', 'margin', 'padding', 'width', 'max-width', 'min-width',
         # tables
         'border-collapse', 'border-spacing', 'caption-side', 'empty-cells', 'table-layout']
 
@@ -154,7 +155,7 @@ class _Cleaner(clean.Cleaner):
                 if style[0].lower() in self._style_whitelist:
                     valid_styles[style[0].lower()] = style[1]
             if valid_styles:
-                el.attrib['style'] = '; '.join('%s: %s' % (key, val) for (key, val) in valid_styles.items())
+                el.attrib['style'] = '; '.join('%s:%s' % (key, val) for (key, val) in valid_styles.items())
             else:
                 del el.attrib['style']
 
@@ -523,11 +524,14 @@ def decode_smtp_header(smtp_header):
     text. email.header decode_header method return a decoded string and its
     charset for each decoded par of the header. This method unicodes the
     decoded header and join them in a complete string. """
+    if isinstance(smtp_header, Header):
+        smtp_header = ustr(smtp_header)
     if smtp_header:
         text = decode_header(smtp_header.replace('\r', ''))
         # The joining space will not be needed as of Python 3.3
-        # See https://hg.python.org/cpython/rev/8c03fe231877
-        return ' '.join([ustr(x[0], x[1]) for x in text])
+        # See https://github.com/python/cpython/commit/07ea53cb218812404cdbde820647ce6e4b2d0f8e
+        sep = ' ' if pycompat.PY2 else ''
+        return sep.join([ustr(x[0], x[1]) for x in text])
     return u''
 
 # was mail_thread.decode_header()
